@@ -1,32 +1,11 @@
 """Simple configuration management with python"""
-__version__ = "0.1.11"
+__version__ = "0.2.1"
 import re
 import ast
 from os import path
 from collections import OrderedDict
 from contextlib import contextmanager
-from box import BoxList, ConfigBox as _ConfigBox
-
-class ConfigBox(_ConfigBox): # pragma: no cover
-
-	def update(self, item=None, **kwargs):
-		if not item:
-			item = kwargs
-		iter_over = item.items() if hasattr(item, 'items') else item
-		for k, v in iter_over:
-			if isinstance(v, dict):
-				# Box objects must be created in case they are already
-				# in the `converted` box_config set
-				#v = ConfigBox(v)
-				if k in self and isinstance(self[k], dict):
-					self[k].update(v)
-					continue
-			#if isinstance(v, list) and not isinstance(v, self._box_config['box_intact_types']):
-			#	v = BoxList(v)
-			try:
-				self.__setattr__(k, v)
-			except (AttributeError, TypeError):
-				self.__setitem__(k, v)
+from diot import Diot
 
 class FormatNotSupported(Exception):
 	"""Raised if format not supported"""
@@ -214,7 +193,7 @@ LOADERS = dict(
 	dict   = DictLoader
 )
 
-class Config(ConfigBox):
+class Config(Diot):
 	"""The main class"""
 	def __init__(self, *args, **kwargs):
 		self.__dict__['_protected'] = dict(
@@ -224,7 +203,6 @@ class Config(ConfigBox):
 			cached       = OrderedDict(),
 			profiles     = set(['default'])
 		)
-		kwargs['box_intact_types'] = kwargs.get('box_intact_types', [list, Config])
 		super(Config, self).__init__(*args, **kwargs)
 
 	def _load(self, *names):
